Name:           curaengine
Epoch:          1
Version:        5.4.0
Release:        %mkrel 1
Group:          Sciences/Computer science
Summary:        Engine for processing 3D models into G-code instructions for 3D printers
License:        AGPL-3.0-or-later
URL:            https://github.com/Ultimaker/CuraEngine
Source0:        %{url}/archive/%{version}.tar.gz#/CuraEngine-%{version}.tar.gz

# Cmake bits taken from 4.13.1, before upstream went nuts with conan
Source2:        FindGMock.cmake
Source3:        FindPolyclipping.cmake
Source4:        FindStb.cmake
Source5:        CMakeLists.txt
Source6:        CPackConfig.cmake

# This is some kind of "public" layer of a private logging thing :/
# It's header-only and not usable as a system library,
# so I (churchyard) decided to bundle it for now. Shame on me.
# It's AGPL-3.0-or-later.
%global scripta_version c378c837eeb505146ab67abe0904bfed2099128f
Source7:        https://github.com/Ultimaker/Scripta_public/archive/%{scripta_version}/Scripta_public-%{scripta_version}.tar.gz
Provides:       bundled(scripta) = %{scripta_version}
# The cmake stuff would attempt to git clone this:
# TODO package on it's own
# commit at Jan 29, 2023
%global stb_commit 5736b15f7ea0ffb08dd38af21067c314d6a3aae9
Source8:	https://github.com/nothings/stb/archive/%{stb_commit}/stb-%{stb_commit}.tar.gz

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  cmake(Arcus)
BuildRequires:  pkgconfig(polyclipping) >= 6.1.2
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  protobuf-devel
BuildRequires:  cmake
BuildRequires:  git-core
BuildRequires:  boost-devel
BuildRequires:  range-v3
BuildRequires:  fmt-devel
BuildRequires:  spdlog-devel

Patch0:         CuraEngine-static-libstdcpp.patch
# Patch for fmtlib 10, from https://github.com/Ultimaker/CuraEngine/commit/5a4ca90594f965b6a5e6af626a5c508185277162
Patch1:         CuraEngine-5.4.0-fmt10.patch


%description
CuraEngine is a C++ console application for 3D printing G-code generation. It
has been made as a better and faster alternative to the old Skeinforge engine.

This is just a console application for G-code generation. For a full graphical
application look at cura with is the graphical frontend for CuraEngine.

%prep
%setup -q -n CuraEngine-%{version} -a8

mv stb-%{stb_commit} stb
cp stb/stb_image.h include/
mkdir cmake
cp -a %{SOURCE2} %{SOURCE3} %{SOURCE4} cmake
rm -rf CMakeLists.txt
cp -a %{SOURCE5} %{SOURCE6} .

tar xf %{SOURCE7}
mv Scripta_public-%{scripta_version}/include/scripta/ include/

%patch -P0 -p1
%patch -P1 -p1

# bundled libraries
rm -rf libs


%build
%cmake \
  -DSET_RPATH:BOOL=OFF \
  -DBUILD_SHARED_LIBS:BOOL=OFF \
  -DCURA_ENGINE_VERSION:STRING=%{version} \
  -DUSE_SYSTEM_LIBS:BOOL=ON \
  -DCMAKE_CXX_FLAGS_RELEASE_INIT:STRING="%{optflags} -fPIC" \
  -DStb_INCLUDE_DIRS:PATH==%{_builddir}/CuraEngine-%{version}/stb
%cmake_build


%install
%cmake_install


%check
# Smoke test
%{buildroot}%{_bindir}/CuraEngine help

%files
%doc LICENSE README.md
%{_bindir}/CuraEngine


%changelog
* Wed Jul 03 2024 papoteur <papoteur> 1:5.4.0-1.mga10
+ Revision: 2079263
- new version 5.4

* Wed Mar 08 2023 papoteur <papoteur> 1:4.13.1-1.mga9
+ Revision: 1948382
- new 4.13.1

* Thu Dec 22 2022 wally <wally> 1:4.12.1-3.mga9
+ Revision: 1925780
- rebuild for protobuf 21.12

* Wed Mar 30 2022 umeabot <umeabot> 1:4.12.1-2.mga9
+ Revision: 1834280
- Mageia 9 Mass Rebuild

* Wed Dec 29 2021 wally <wally> 1:4.12.1-1.mga9
+ Revision: 1765239
- new version 4.12.1
- rebuild for protobuf 3.19.1

* Tue Nov 16 2021 ns80 <ns80> 1:4.8.0-2.mga9
+ Revision: 1757182
- add patch curaengine-4.8.0-mga-fix-rpath-error
- stb_image: update to latest git snapshot + some pending pull requests for CVE-2021-28021, CVE-2021-42715, and CVE-2021-42716 (mga#29622)

* Mon Dec 28 2020 daviddavid <daviddavid> 1:4.8.0-1.mga8
+ Revision: 1664576
- new version: 4.8.0

* Fri Dec 18 2020 luigiwalser <luigiwalser> 1:4.4.1-4.mga8
+ Revision: 1661000
- rebuild for protobuf

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1:4.4.1-3.mga8
+ Revision: 1650716
- rebuild for protobuf

* Sun Jun 28 2020 daviddavid <daviddavid> 1:4.4.1-2.mga8
+ Revision: 1600167
- rebuild for new protobuf 3.12.3

* Mon Feb 24 2020 daviddavid <daviddavid> 1:4.4.1-1.mga8
+ Revision: 1549923
- new version: 4.4.1 (add epoch as upstream changed its version scheme)
- switch to cmake build system
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 15.04-5.mga7
+ Revision: 1297374
- Mageia 7 Mass Rebuild

* Mon Sep 19 2016 akien <akien> 15.04-4.mga6
+ Revision: 1054418
- Rebuild again for polyclipping, for real this time

* Mon Sep 19 2016 akien <akien> 15.04-3.mga6
+ Revision: 1054301
- Rebuild for polyclipping 6.4

* Wed Dec 30 2015 ycantin <ycantin> 15.04-1.mga6
+ Revision: 916995
- initial import
- Created package structure for curaengine.

